@@ -23,7 +23,7 @@ def get_latest_proj():
     return max(projectcodes) + 1
 
 
-def create_project_on_fileserver(project):
+def create_project_on_fileserver(project, internal=False):
 
     if platform.system() == "Windows":
         project_dir = f"{proj_dir_windows}/{project}/"
@@ -40,8 +40,8 @@ def create_project_on_fileserver(project):
     mv = os.path.join(project_dir, "Mails&Vergaderingen")
     print(f"{mv} already exists") if os.path.isdir(mv) else os.makedirs(mv)
 
-    maps = os.path.join(project_dir, "Maps")
-    print(f"{maps} already exists") if os.path.isdir(maps) else os.makedirs(maps)
-
-    scenes = os.path.join(project_dir, "scenes")
-    print(f"{scenes} already exists") if os.path.isdir(scenes) else os.makedirs(scenes)
+    if internal:
+        maps = os.path.join(project_dir, "Maps")
+        print(f"{maps} already exists") if os.path.isdir(maps) else os.makedirs(maps)
+        scenes = os.path.join(project_dir, "scenes")
+        print(f"{scenes} already exists") if os.path.isdir(scenes) else os.makedirs(scenes)
