@@ -1,7 +1,7 @@
 from pick import pick
 
 from ftrack_ams.fileserver import create_project_on_fileserver, get_latest_proj
-from ftrack_ams.functions import clearConsole, select_artist
+from ftrack_ams.functions import clearConsole, get_int_from_user, select_artist
 from ftrack_ams.functions import create_project_name
 
 
@@ -18,17 +18,16 @@ def create_new_project(session):
     projects = session.query("Project")
     users = session.query("User")
 
-    internal_project_handle = session.query('Project where name is "Team_Intern"').one()
+    logo_handle = session.query('Folder where name is "AMSVFB_Logo"').one()
 
-    for c in internal_project_handle["children"]:
-        if c["name"] == "Assets":
-            for a in c["children"]:
-                if a["name"] == "VFB-LOGO":
-                    vfb_thumb = a["thumbnail_id"]
-                if a["name"] == "AMSVFB-LOGO":
-                    amsvfb_thumb = a["thumbnail_id"]
-                if a["name"] == "AMS-LOGO":
-                    ams_thumb = a["thumbnail_id"]
+    for logo in logo_handle["children"]:
+        print(logo)
+        if logo["name"] == "VFB-LOGO":
+            vfb_thumb = logo["thumbnail_id"]
+        if logo["name"] == "AMSVFB-LOGO":
+            amsvfb_thumb = logo["thumbnail_id"]
+        if logo["name"] == "AMS-LOGO":
+            ams_thumb = logo["thumbnail_id"]
 
     clearConsole()
 
@@ -37,6 +36,7 @@ def create_new_project(session):
     option, index = pick(
         sorted([p["name"] for p in projects if "invoice" not in p["name"]]),
         "Select the team:",
+        indicator="👉",
     )
 
     clearConsole()
@@ -55,15 +55,16 @@ def create_new_project(session):
 
     for a in team["allocations"]:
         resource = a["resource"]
-        if isinstance(resource, session.types['User']):
+        if isinstance(resource, session.types["User"]):
             user = resource
             project_team.append(user)
 
     internal_project = True if "Intern" in team["name"] else False
 
     if internal_project:
-        departement_choice, departement_index = pick(["AMS", "VFB"],
-                                                     "Select internal department:")
+        departement_choice, departement_index = pick(
+            ["AMS", "VFB"], "Select internal department:"
+        )
 
     project_thumb = amsvfb_thumb
 
@@ -110,17 +111,8 @@ def create_new_project(session):
         else:
             print(f"Number of INT:{num_int}")
             break
-
-    while True:
-        try:
-            num_ext = int(input("Enter amount of EXT shots:\n"))
-        except ValueError:
-            print("Sorry, I didn't understand that? Did you type a number?")
-            # better try again... Return to the start of the loop
-            continue
-        else:
-            print(f"Number of EXT:{num_ext}")
-            break
+    num_int = get_int_from_user("Enter amount of INT shots: ")
+    num_ext = get_int_from_user("Enter amount of EXT shots: ")
 
     if num_int == 0:
         desc = f"{num_ext} EXT"
@@ -130,19 +122,25 @@ def create_new_project(session):
         desc = f"{num_int} INT/{num_ext} EXT"
 
     if internal_project and departement_choice == "VFB":
-        proj = session.create("Vfbproj", {
-                              "name": project_name,
-                              "parent": dest_folder,
-                              "description": desc,
-                              "thumbnail_id": project_thumb}
-                              )
+        proj = session.create(
+            "Vfbproj",
+            {
+                "name": project_name,
+                "parent": dest_folder,
+                "description": desc,
+                "thumbnail_id": project_thumb,
+            },
+        )
     else:
-        proj = session.create("Amsproj", {
-                              "name": project_name,
-                              "parent": dest_folder,
-                              "description": desc,
-                              "thumbnail_id": project_thumb}
-                              )
+        proj = session.create(
+            "Amsproj",
+            {
+                "name": project_name,
+                "parent": dest_folder,
+                "description": desc,
+                "thumbnail_id": project_thumb,
+            },
+        )
 
     task_templates = team["project_schema"]["task_templates"]
 
@@ -160,36 +158,40 @@ def create_new_project(session):
     project_manager = mgmt[index]
 
     for task_type in [t["task_type"] for t in production_template["items"]]:
-        task = session.create("Task",
-                              {"name": task_type["name"],
-                               "type": task_type,
-                               "thumbnail_id": project_thumb,
-                               "parent": proj})
-        session.create("Appointment", {
-                       "context": task,
-                       "resource": project_manager,
-                       "type": "assignment"},
-                       )
+        task = session.create(
+            "Task",
+            {
+                "name": task_type["name"],
+                "type": task_type,
+                "thumbnail_id": project_thumb,
+                "parent": proj,
+            },
+        )
+        session.create(
+            "Appointment",
+            {"context": task, "resource": project_manager, "type": "assignment"},
+        )
 
     for task_type in [t["task_type"] for t in annelies_template["items"]]:
-        task = session.create("Task", {
-                              "name": task_type["name"],
-                              "type": task_type,
-                              "thumbnail_id": project_thumb,
-                              "parent": proj}
-                              )
+        task = session.create(
+            "Task",
+            {
+                "name": task_type["name"],
+                "type": task_type,
+                "thumbnail_id": project_thumb,
+                "parent": proj,
+            },
+        )
 
-        session.create("Appointment", {
-                       "context": task,
-                       "resource": annelies,
-                       "type": "assignment"}
-                       )
+        session.create(
+            "Appointment", {"context": task, "resource": annelies, "type": "assignment"}
+        )
 
     if num_int > 0:
-        int_folder = session.create("Folder", {
-                                    "name": f"{num}_INT",
-                                    "parent": proj,
-                                    "thumbnail_id": project_thumb})
+        int_folder = session.create(
+            "Folder",
+            {"name": f"{num}_INT", "parent": proj, "thumbnail_id": project_thumb},
+        )
 
         if len(project_team) > 1:
             int_artist = select_artist(project_team, users, "Select INT artist: ")
@@ -199,31 +201,35 @@ def create_new_project(session):
         for i in range(num_int):
             int_shot_name = f"{num}_INT_{chr(ord('@')+i+1)}"
 
-            int_shot = session.create("Image", {
-                                      "name": int_shot_name,
-                                      "parent": int_folder,
-                                      "thumbnail_id": project_thumb}
-                                      )
+            int_shot = session.create(
+                "Image",
+                {
+                    "name": int_shot_name,
+                    "parent": int_folder,
+                    "thumbnail_id": project_thumb,
+                },
+            )
 
             for task_type in [t["task_type"] for t in image_template["items"]]:
-                task = session.create("Task", {
-                                      "name": task_type["name"],
-                                      "type": task_type,
-                                      "parent": int_shot,
-                                      "thumbnail_id": project_thumb},
-                                      )
-                session.create("Appointment", {
-                               "context": task,
-                               "resource": int_artist,
-                               "type": "assignment"},
-                               )
+                task = session.create(
+                    "Task",
+                    {
+                        "name": task_type["name"],
+                        "type": task_type,
+                        "parent": int_shot,
+                        "thumbnail_id": project_thumb,
+                    },
+                )
+                session.create(
+                    "Appointment",
+                    {"context": task, "resource": int_artist, "type": "assignment"},
+                )
 
     if num_ext > 0:
-        ext_folder = session.create("Folder", {
-                                    "name": f"{num}_EXT",
-                                    "parent": proj,
-                                    "thumbnail_id": project_thumb}
-                                    )
+        ext_folder = session.create(
+            "Folder",
+            {"name": f"{num}_EXT", "parent": proj, "thumbnail_id": project_thumb},
+        )
 
         if len(project_team) > 1:
             ext_artist = select_artist(project_team, users, "Select EXT artist: ")
@@ -232,18 +238,24 @@ def create_new_project(session):
 
         for i in range(num_ext):
             ext_shot_name = f"{num}_EXT_{chr(ord('@')+i+1)}"
-            ext_shot = session.create("Image", {
-                                      "name": ext_shot_name,
-                                      "parent": ext_folder,
-                                      "thumbnail_id": project_thumb}
-                                      )
+            ext_shot = session.create(
+                "Image",
+                {
+                    "name": ext_shot_name,
+                    "parent": ext_folder,
+                    "thumbnail_id": project_thumb,
+                },
+            )
             for task_type in [t["task_type"] for t in image_template["items"]]:
-                task = session.create("Task", {
-                                      "name": task_type["name"],
-                                      "type": task_type,
-                                      "parent": ext_shot,
-                                      "thumbnail_id": project_thumb},
-                                      )
+                task = session.create(
+                    "Task",
+                    {
+                        "name": task_type["name"],
+                        "type": task_type,
+                        "parent": ext_shot,
+                        "thumbnail_id": project_thumb,
+                    },
+                )
                 session.create(
                     "Appointment",
                     {"context": task, "resource": ext_artist, "type": "assignment"},
@@ -257,16 +269,23 @@ def create_new_project(session):
     if internal_project:
         for artist in project_set:
             for task_type in [t["task_type"] for t in timetrack_template["items"]]:
-                task = session.create("Task", {
-                                      "name": f"TT_{artist['first_name']}",
-                                      "type": task_type,
-                                      "thumbnail_id": project_thumb,
-                                      "parent": proj})
-                session.create("Appointment", {
-                               "context": task,
-                               "resource": project_manager,
-                               "type": "assignment"},
-                               )
+                task = session.create(
+                    "Task",
+                    {
+                        "name": f"TT_{artist['first_name']}",
+                        "type": task_type,
+                        "thumbnail_id": project_thumb,
+                        "parent": proj,
+                    },
+                )
+                session.create(
+                    "Appointment",
+                    {
+                        "context": task,
+                        "resource": project_manager,
+                        "type": "assignment",
+                    },
+                )
 
     drone = get_yes_no("Does the project require photography?")
 
@@ -276,8 +295,12 @@ def create_new_project(session):
     print(f"--- creating objects for {project_name} on ftrack")
     print(f"--- creating outlook folder for {project_name}")
     print(f"--- creating directory for {project_name} on X:/")
-    print(f"-- {num_int} INT tasks for {int_artist['username']}") if num_int > 0 else None
-    print(f"-- {num_ext} EXT tasks for {ext_artist['username']}") if num_ext > 0 else None
+    print(
+        f"-- {num_int} INT tasks for {int_artist['username']}"
+    ) if num_int > 0 else None
+    print(
+        f"-- {num_ext} EXT tasks for {ext_artist['username']}"
+    ) if num_ext > 0 else None
     print("--- creating photography tasks") if drone else None
     print(f"--- creating {project_name}.mxp for 3dsmax project")
     print(f"--- updating {project_name} on teamleader")
